summaryrefslogtreecommitdiff
path: root/qa/qa/page/settings/common.rb
diff options
context:
space:
mode:
Diffstat (limited to 'qa/qa/page/settings/common.rb')
-rw-r--r--qa/qa/page/settings/common.rb20
1 files changed, 9 insertions, 11 deletions
diff --git a/qa/qa/page/settings/common.rb b/qa/qa/page/settings/common.rb
index a683a6829d5..f9f71aa4a72 100644
--- a/qa/qa/page/settings/common.rb
+++ b/qa/qa/page/settings/common.rb
@@ -4,19 +4,17 @@ module QA
module Common
# Click the Expand button present in the specified section
#
- # @param [String] name present in the container in the DOM
- def expand_section(name)
- page.within('#content-body') do
- page.within('section', text: name) do
- # Because it is possible to click the button before the JS toggle code is bound
- wait(reload: false) do
- click_button 'Expand' unless first('button', text: 'Collapse')
+ # @param [Symbol] and `element` name defined in a `view` block
+ def expand_section(element_name)
+ within_element(element_name) do
+ # Because it is possible to click the button before the JS toggle code is bound
+ wait(reload: false) do
+ click_button 'Expand' unless first('button', text: 'Collapse')
- page.has_content?('Collapse')
- end
-
- yield if block_given?
+ page.has_content?('Collapse')
end
+
+ yield if block_given?
end
end
end